@@ -23,7 +23,7 @@ Or install globally:
     mapify check
 """
 
-__version__ = "2.0.0"
+__version__ = "2.2.0"
 
 import copy
 import os
@@ -1058,6 +1058,31 @@ Return valid=false if:
 """
 
 
+def create_reference_files(project_path: Path) -> int:
+    """Create MAP reference files in .claude/references/
+
+    Returns:
+        Number of reference files installed
+    """
+    references_dir = project_path / ".claude" / "references"
+    references_dir.mkdir(parents=True, exist_ok=True)
+
+    # Get templates directory
+    templates_dir = get_templates_dir()
+    references_template_dir = templates_dir / "references"
+
+    count = 0
+    if references_template_dir.exists():
+        import shutil
+
+        for ref_file in references_template_dir.glob("*.md"):
+            dest_file = references_dir / ref_file.name
+            shutil.copy2(ref_file, dest_file)
+            count += 1
+
+    return count
+
+
 def create_command_files(project_path: Path) -> None:
     """Create MAP slash commands in .claude/commands/"""
     commands_dir = project_path / ".claude" / "commands"
@@ -1163,6 +1188,45 @@ def create_skill_files(project_path: Path) -> int:
     return count
 
 
+def create_map_tools(project_path: Path) -> int:
+    """Create .map/ directory with static analysis tools."""
+    import shutil
+
+    map_dir = project_path / ".map"
+    map_dir.mkdir(parents=True, exist_ok=True)
+
+    # Get templates directory
+    templates_dir = get_templates_dir()
+    map_template_dir = templates_dir / "map"
+
+    count = 0
+    if map_template_dir.exists():
+        # Copy static-analysis directory
+        static_analysis_src = map_template_dir / "static-analysis"
+        if static_analysis_src.exists():
+            static_analysis_dest = map_dir / "static-analysis"
+            if static_analysis_dest.exists():
+                try:
+                    shutil.rmtree(static_analysis_dest)
+                except (OSError, PermissionError) as e:
+                    # Log warning but continue - old scripts may be in use
+                    import sys
+
+                    print(
+                        f"Warning: Could not remove existing {static_analysis_dest}: {e}",
+                        file=sys.stderr,
+                    )
+            shutil.copytree(
+                static_analysis_src, static_analysis_dest, dirs_exist_ok=True
+            )
+            # Make scripts executable
+            for script in static_analysis_dest.rglob("*.sh"):
+                script.chmod(script.stat().st_mode | 0o755)
+                count += 1
+
+    return count
+
+
 def configure_global_permissions() -> None:
     """Configure global Claude Code permissions for read-only commands"""
     claude_dir = Path.home() / ".claude"
@@ -1935,6 +1999,18 @@ def init(
     skill_word = "skill" if skill_count == 1 else "skills"
     tracker.complete("create-skills", f"{skill_count} {skill_word}")
 
+    tracker.add("create-references", "Create reference files")
+    tracker.start("create-references")
+    ref_count = create_reference_files(project_path)
+    ref_word = "file" if ref_count == 1 else "files"
+    tracker.complete("create-references", f"{ref_count} {ref_word}")
+
+    tracker.add("create-map-tools", "Create MAP tools")
+    tracker.start("create-map-tools")
+    tool_count = create_map_tools(project_path)
+    tool_word = "script" if tool_count == 1 else "scripts"
+    tracker.complete("create-map-tools", f"{tool_count} {tool_word}")
+
     if selected_mcp_servers:
         # Create internal MCP config (for MAP Framework agent mappings)
         tracker.add("mcp-config", "Create internal MCP config")
